@@ -3,8 +3,9 @@ from functools import wraps
 from typing import TYPE_CHECKING, Any, Callable, Dict, Iterable, Optional, Union
 
 from ..coin import Coin
-from ..errors import InvalidEventError, LightningDisabledError
+from ..errors import LightningDisabledError
 from ..event_delivery import EventDelivery
+from ..logger import logger
 from ..providers.jsonrpcrequests import RPCProxy
 from ..types import AmountType
 from ..utils import bitcoins, call_universal, convert_amount_type
@@ -18,7 +19,7 @@ def lightning(f: Callable) -> Callable:
     async def wrapper(*args: Any, **kwargs: Any) -> Any:
         if len(args) > 0:
             obj = args[0]
-            if not await obj.get_config("lightning"):
+            if not await obj.get_config("lightning"):  # pragma: no cover: can't be changed during tests
                 raise LightningDisabledError("Lightning is disabled in current daemon.")
         return await f(*args, **kwargs)
 
@@ -31,7 +32,7 @@ class BTC(Coin, EventDelivery):
     RPC_URL = "http://localhost:5000"
     RPC_USER = "electrum"
     RPC_PASS = "electrumz"
-    ALLOWED_EVENTS = ["new_block", "new_transaction", "new_payment"]
+    ALLOWED_EVENTS = ["new_block", "new_transaction", "new_payment", "verified_tx"]
     BALANCE_ATTRS = ["confirmed", "unconfirmed", "unmatured", "lightning"]
 
     def __init__(
@@ -73,10 +74,10 @@ class BTC(Coin, EventDelivery):
     async def help(self) -> list:
         return await self.server.help()  # type: ignore
 
-    async def get_tx(self, tx: str) -> dict:
+    async def get_tx(self, tx: str) -> dict:  # pragma: no cover: see tests for explanation
         return await self.server.get_transaction(tx)  # type: ignore
 
-    async def get_address(self, address: str) -> list:
+    async def get_address(self, address: str) -> list:  # pragma: no cover
         out: list = await self.server.getaddresshistory(address)
         for i in out:
             i["tx"] = await self.get_tx(i["tx_hash"])
@@ -89,6 +90,25 @@ class BTC(Coin, EventDelivery):
     async def _add_request(self, *args: Any, **kwargs: Any) -> dict:
         return await self.server.add_request(*args, **kwargs)  # type: ignore
 
+    def _convert_amounts(self, data: dict) -> dict:
+        if data[self.amount_field].lower() != "unknown":
+            data[self.amount_field] = convert_amount_type(data[self.amount_field])
+        return data
+
+    async def _add_request_base(
+        self,
+        method: Callable,
+        amount: Optional[AmountType] = None,
+        description: str = "",
+        expire: Union[int, float] = 15,
+        extra_kwargs: dict = {},
+    ) -> dict:
+        expiration = 60 * expire if expire else None
+        kwargs = {"amount": amount, "memo": description, "expiration": expiration}
+        kwargs.update(extra_kwargs)
+        data = await method(**kwargs)
+        return self._convert_amounts(data)
+
     async def add_request(
         self,
         amount: Optional[AmountType] = None,
@@ -114,11 +134,7 @@ class BTC(Coin, EventDelivery):
         Returns:
             dict: Invoice data
         """
-        expiration = 60 * expire if expire else None
-        data = await self._add_request(amount=amount, memo=description, expiration=expiration, force=True)
-        if data[self.amount_field].lower() != "unknown":
-            data[self.amount_field] = convert_amount_type(data[self.amount_field])
-        return data
+        return await self._add_request_base(self._add_request, amount, description, expire, extra_kwargs={"force": True})
 
     async def get_request(self, address: str) -> dict:
         """Get invoice info
@@ -138,9 +154,7 @@ class BTC(Coin, EventDelivery):
             dict: Invoice data
         """
         data = await self.server.getrequest(address)
-        if data[self.amount_field].lower() != "unknown":
-            data[self.amount_field] = convert_amount_type(data[self.amount_field])
-        return data  # type: ignore
+        return self._convert_amounts(data)
 
     async def history(self) -> dict:
         """Get transaction history of wallet
@@ -163,22 +177,22 @@ class BTC(Coin, EventDelivery):
 
     async def process_updates(self, updates: Iterable[dict], *args: Any, pass_instance: bool = False, **kwargs: Any) -> None:
         if not isinstance(updates, list):
+            logger.debug(f"Invalid updates passed: {updates}")
             return
         for event_info in updates:
             if not isinstance(event_info, dict):
+                logger.debug(f"{event_info} is not a dict")
                 continue
             event = event_info.pop("event", None)
             if not event or event not in self.ALLOWED_EVENTS:
-                raise InvalidEventError(f"Invalid event from server: {event}")
+                logger.error(f"Invalid event from server: {event}")
+                continue
             handler = self.event_handlers.get(event)
             if handler:
                 args = (event,)
                 if pass_instance:
                     args = (self,) + args
-                try:
-                    await call_universal(handler, *args, **event_info)
-                except Exception:
-                    pass
+                await call_universal(handler, *args, **event_info)
 
     async def pay_to(
         self,
@@ -452,25 +466,32 @@ class BTC(Coin, EventDelivery):
         return await self.server.open_channel(node_id, amount)  # type: ignore
 
     @lightning
-    async def add_invoice(self, amount: AmountType, message: Optional[str] = "") -> str:
-        """Create lightning invoice
+    async def add_invoice(
+        self,
+        amount: AmountType,
+        description: str = "",
+        expire: Union[int, float] = 15,
+    ) -> dict:
+        """Create a lightning invoice
 
-        Create lightning invoice and return bolt invoice id
+        Create a lightning invoice and return invoice data with bolt invoice id
+        All parameters are the same as in add_request
 
         Example:
 
-        >>> a.add_invoice(0.5)
-        'lnbc500m1pwnt87fpp5d60sykcjd2swk72t3g0njwmdytfe4fu65fz5v...'
+        >>> a.add_invoice(0.5, "My invoice", 20)
+        {'time': 1562762334, 'amount': 50000000, 'exp': 1200, 'invoice': 'lnbc500m',...
 
         Args:
             self (BTC): self
-            amount (AmountType): invoice amount
-            message (Optional[str], optional): Invoice message. Defaults to "".
+            amount (AmountType): amount to open invoice
+            description (str, optional): Description of invoice. Defaults to "".
+            expire (Union[int, float], optional): The time invoice will expire in. In minutes. Defaults to 15.
 
         Returns:
-            str: bolt invoice id
+            dict: Invoice data
         """
-        return await self.server.add_lightning_request(amount, message)  # type: ignore
+        return await self._add_request_base(self.server.add_lightning_request, amount, description, expire)
 
     @lightning
     async def close_channel(self, channel_id: str, force: bool = False) -> str:
@@ -562,3 +583,23 @@ class BTC(Coin, EventDelivery):
             list: list of channels
         """
         return await self.server.list_channels()  # type: ignore
+
+    @lightning
+    async def get_invoice(self, rhash: str) -> dict:
+        """Get lightning invoice info
+
+        Get lightning invoice information by rhash got from add_invoice
+
+        Example:
+
+        >>> c.get_invoice("e34d7fb4cda66e0760fc193496c302055d0fd960cfd982432355c8bfeecd5f33")
+        {'is_lightning': True, 'amount_BTC': Decimal('0.5'), 'timestamp': 1619273042, 'expiration': 900, ...
+
+        Args:
+            rhash (str): invoice rhash
+
+        Returns:
+            dict: invoice data
+        """
+        data = await self.server.get_invoice(rhash)
+        return self._convert_amounts(data)
