@@ -9,9 +9,9 @@ from bitcart import BTC
 from bitcart.coin import Coin
 
 TEST_XPUB = "zprvAWgYBBk7JR8GkUwcwyhT1qk8FQpym8cHboGyDEdMhHcL1NRe8bioZR3uo5gTSTG47iqQX6VqPL6iHHDNK55taJiV9MEscu6UiqSR1tAiSUq"
-REGTEST_XPUB = (
-    "vprv9DMUxX4ShgxMMQduKMSnoNsX4jZjdqmRRapGRRFbok1XXrjkvFyAnvSVPbs4t8ZDA73fTT9DLzdCyHBh39AZHG8nsP1gEj11EwSdYP8zhKF"
-)
+# deterministic channels support only seeds
+REGTEST_XPUB = "dutch field mango comfort symptom smooth wide senior tongue oyster wash spoon"
+REGTEST_XPUB2 = "hungry ordinary similar more spread math general wire jealous valve exhaust emotion"
 LIGHTNING_UNSUPPORTED_XPUB = (
     "xprv9s21ZrQH143K3tZPHG8CbfZ7uUY5stdHmaEXeSqawGrZuAoBdHPgKHjdkfmHSdxDJSbo29JiU1PcWhzEsgFryqMHQfr2T5TWBPK8EqFjscZ"
 )
@@ -48,8 +48,13 @@ async def regtest_wallet():
 
 
 @pytest.fixture
-async def regtest_node_id():
-    return await BTC(xpub=REGTEST_XPUB, rpc_url="http://localhost:5110").node_id
+async def regtest_node():
+    return BTC(xpub=REGTEST_XPUB2, rpc_url="http://localhost:5110")
+
+
+@pytest.fixture
+async def regtest_node_id(regtest_node):
+    return await regtest_node.node_id
 
 
 @pytest.fixture
@@ -114,6 +119,11 @@ class FakeBadJSONDaemon(FakeDaemon):
         await ws.send_str("")
 
 
+class FakeBadCurrencyDaemon(FakeDaemon):
+    async def reply_to_websocket(self, ws):
+        await ws.send_json({"currency": "test", "updates": [{"event": "new_transaction", "tx": "test"}]})
+
+
 async def patched_session_maker(daemon_class):
     fake_daemon = daemon_class()
     info = await fake_daemon.start()
@@ -135,3 +145,10 @@ async def patched_session_bad_json():
     session, daemon = await patched_session_maker(FakeBadJSONDaemon)
     yield session
     await daemon.stop()
+
+
+@pytest.fixture
+async def patched_session_bad_currency():
+    session, daemon = await patched_session_maker(FakeBadCurrencyDaemon)
+    yield session
+    await daemon.stop()
